pub struct TileModel {
pub id: TileId,
pub config: TileConfig,
pub properties: JsonObject,
pub folder_id: FolderId,
pub plugin_id: PluginId,
pub action_id: ActionId,
pub position: TilePosition,
}Fields
id: TileIdUnique ID of the tile
config: TileConfigConfiguration for the tile and how it appears in the UI
properties: JsonObjectProperties / settings defined on this specific tile
folder_id: FolderIdID of the folder this tile is within
plugin_id: PluginIdID of the plugin the action_id is apart of
action_id: ActionIdID of the action within the plugin to execute
position: TilePositionPosition of the tile